<?php

declare(strict_types=1);

namespace Drupal\role_enum\Dtt;

use Drupal\Core\Session\AccountInterface;
use Drupal\role_enum\Enum\ConfigBackedRoleInterface;
use Drupal\role_enum\RoleMapping;
use Drupal\user\Entity\Role;

trait RoleEnumTestTrait {

  /**
   * Tests all roles present on the real site are all represented by enum cases.
   */
  final public function testAllRolesPresent(): void {
    $ids = [];

    /** @var \Drupal\role_enum\RoleMapping $mapping */
    $mapping = \Drupal::service(RoleMapping::class);
    foreach ($mapping->getEnumClasses() as $enumClass) {
      foreach ($enumClass::cases() as $case) {
        \assert($case instanceof ConfigBackedRoleInterface);
        $ids[] = $mapping->getId($case);
      }
    }

    $actualIds = \array_keys(Role::loadMultiple());
    $actualIds = \array_diff($actualIds, [
      // Remove roles since these are not "assignable".
      AccountInterface::ANONYMOUS_ROLE,
      AccountInterface::AUTHENTICATED_ROLE,
    ]);

    // Asserts all roles are present, ignoring order.
    // "-" values are roles which are missing cases.
    // "+" values are cases which do not have matching roles.
    static::assertEqualsCanonicalizing(
      $actualIds,
      $ids,
    );
  }

}
