<?php

declare(strict_types=1);

namespace Drupal\role_enum\EntityProperty;

use Drupal\role_enum\Entity\RoleInterface;
use Drupal\role_enum\Enum\RoleInterface as RoleEnumInterface;

/**
 * @template-covariant T of \Drupal\role_enum\Entity\RoleInterface
 */
final class RoleEnumProxy {

  /**
   * @phpstan-param T $entity
   */
  private function __construct(
    private readonly RoleInterface $entity,
  ) {
  }

  /**
   * Internal factory.
   *
   * Call \Drupal\role_enum\EntityProperty\RoleEnumProp::createProperty instead.
   *
   * @phpstan-param T $entity
   * @phpstan-return static<T>
   * @internal
   */
  public static function init(RoleInterface $entity): static {
    return new static($entity);
  }

  /**
   * @phpstan-return T
   */
  public function add(RoleEnumInterface ...$roles) {
    $this->entity->roleEnumAdd(...$roles);
    return $this->entity;
  }

  /**
   * @phpstan-return T
   */
  public function remove(RoleEnumInterface ...$roles) {
    $this->entity->roleEnumRemove(...$roles);
    return $this->entity;
  }

  public function has(RoleEnumInterface $role): bool {
    return $this->entity->roleEnumHas($role);
  }

}
