<?php

declare(strict_types=1);

namespace Drupal\role_enum\Enum;

/**
 * An interface representing roles backed by configuration defined elsewhere.
 *
 * Roles which are defined by YAML must extend this interface.
 */
interface ExternalConfigBackedRoleInterface extends ConfigBackedRoleInterface {

  /**
   * The unique identifier for the role.
   *
   * This interface will use the ID verbatim.
   *
   * The id() method is used to determine a unique ID, so we don't require
   * string backed enums. Role enums can of course be string backed, just return
   * <code>$this->value</code> in <code>id()</code>.
   *
   * This value should be globally unique.
   */
  public function id(): string;

  /**
   * A label for the role.
   *
   * A label mapping can be provided, or be as simple as:
   * <code>Role::load($this->value)->label()</code>
   */
  public function label(): string;

}
