<?php

declare(strict_types=1);

namespace Drupal\role_enum;

/**
 * Converts the cases of #[AsPermissions] enums to permissions.
 *
 * @internal
 */
final class RoleEnumPermissions {

  public function __construct(
    private PermissionMapping $permissionMapping,
  ) {
  }

  /**
   * @phpstan-return array<string, array{title: string, provider: string}>
   */
  public function permissions(): array {
    $permissions = [];

    foreach ($this->permissionMapping->getEnumClasses() as $class) {
      foreach ($class::cases() as $permissionCase) {
        $permissions[$permissionCase->id()] = [
          // @todo PermissionDefinition attr for title and description.
          'title' => $permissionCase->id(),
          'provider' => $this->permissionMapping->getProvider($class),
        ];
      }
    }

    return $permissions;
  }

}
