<?php

declare(strict_types=1);

namespace Drupal\role_enum;

use Drupal\role_enum\Enum\RoleInterface;
use Drupal\role_enum\Exception\UnknownMappingException;

/**
 * @internal
 */
final readonly class RoleMapping {

  /**
   * @phpstan-param array<class-string<\Drupal\role_enum\Enum\RoleInterface>> $enumClasses
   * @phpstan-param array<string, string> $enumIdMap
   * @internal
   */
  public function __construct(
    private array $enumClasses,
    private array $enumIdMap,
  ) {
  }

  /**
   * @phpstan-return array<class-string<\Drupal\role_enum\Enum\RoleInterface>>
   */
  public function getEnumClasses(): array {
    return $this->enumClasses;
  }

  /**
   * @throws \Drupal\role_enum\Exception\UnknownMappingException
   */
  public function getId(RoleInterface $role): string {
    $enumString = \sprintf('%s::%s', $role::class, $role->name);
    return $this->enumIdMap[$enumString] ?? throw UnknownMappingException::create($enumString);
  }

}
