<?php

declare(strict_types=1);

namespace Drupal\Tests\role_enum\Kernel;

use Drupal\Core\Config\ImportStorageTransformer;
use Drupal\Core\Config\MemoryStorage;
use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\Lock\LockBackendInterface;
use Drupal\Core\Lock\NullLockBackend;
use Drupal\KernelTests\KernelTestBase;

/**
 * Tests Role Enum property and trait.
 */
final class InvalidPermissionsTest extends KernelTestBase {

  protected static $modules = [
    'user',
    'bca',
    'role_enum',
    'role_enum_invalid_permission_test',
  ];

  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('user');
  }

  /**
   * @covers \Drupal\role_enum\ConfigTransformer::permissions
   */
  public function testInvalidPermissions(): void {
    $lock = $this->createMock(LockBackendInterface::class);
    $lock->expects(static::once())
      ->method('acquire')
      ->willReturn(TRUE);

    // The import transformer under test.
    $transformer = new ImportStorageTransformer(
      $this->container->get('event_dispatcher'),
      $this->container->get('database'),
      $lock,
      new NullLockBackend(),
    );

    static::expectException(\Exception::class);
    static::expectExceptionMessage('Permission validation failed for Drupal\role_enum_invalid_permission_test\Role\InvalidRoles::Role1, permissions do not exist:');
    static::expectExceptionMessage('`invalid permission string` provided by string on Drupal\role_enum_invalid_permission_test\Role\InvalidRoles::Role1');
    static::expectExceptionMessage('`invalid permission` provided by Drupal\role_enum_invalid_permission_test\Permissions\InvalidPermissions::INVALID_PERMISSION');
    static::expectExceptionMessage('`invalid permission_other` provided by Drupal\role_enum_invalid_permission_test\Permissions\InvalidPermissions::INVALID_PERMISSION_OTHER');
    $transformer->transform(new MemoryStorage());
  }

  public function register(ContainerBuilder $container): void {
    // Test users will get a uid1, make sure it doesn't affect asserts.
    $container->setParameter('security.enable_super_user', FALSE);
  }

}
